@@ -189,8 +189,16 @@ def run(runner, job, docker):
 
         # populate real vars
         for var in job["variables"]:
-            name = var["key"]
-            config["variables"][name] = var["value"]
+            # support 'file' variables
+            if 'file' in var.keys() and var["file"]:
+                filevar = tempfile.NamedTemporaryFile(dir=tempdir, delete=False )
+                filevar.write( str.encode(var["value"]))
+                name = var["key"]
+                config["variables"][name] = filevar.name
+                filevar.close()
+            else:
+                name = var["key"]
+                config["variables"][name] = var["value"]
 
         jobname = job["job_info"]["name"]
         emulator_job = configloader.load_job(config, jobname)
