@@ -124,22 +124,25 @@ if __name__ == "__main__":
                 while not opts.once:
                     interval = 40
                     logmsg.info("Polling for jobs.. ({} sec)".format(interval))
+                    result = False
                     job = run.poll()
                     if not job:
                         time.sleep(interval)
                     else:
-                        result = executor.run(run, job, docker)
-                        exitstatus = result
-                        logmsg.info("Job {} has ended success={}".format(job["id"], result))
-                        if result:
-                            run.success(job)
-                        else:
-                            run.failed(job)
+                        try:
+                            result = executor.run(run, job, docker)
+                            exitstatus = result
+                        finally:
+                            logmsg.info("Job {} has ended success={}".format(job["id"], result))
+                            if result:
+                                run.success(job)
+                            else:
+                                run.failed(job)
 
             except (ConnectionError, HTTPError) as err:
                 logmsg.warning("comms exception {}".format(err))
                 logmsg.warning("sleeping..")
-                time.sleep(90)
+                time.sleep(10)
 
         if exitstatus and opts.once:
             sys.exit(exitstatus)
